import javax.swing.*;
import java.util.*;
import java.util.zip.*;
import java.util.jar.*;
import java.awt.*;
import java.io.*;
import javax.swing.border.*;
import java.util.Locale;
import java.util.ResourceBundle;
import java.text.MessageFormat;
import org.xml.sax.*;
import org.xml.sax.helpers.*;//JAXP 1.1
import javax.xml.parsers.*;
import javax.xml.transform.*;
import javax.xml.transform.stream.*;
import javax.xml.transform.sax.*; 
import java.awt.event.*;

/**
 * This class will make a frame-window where user can select which file inside
 * the jar file that they want to view.
 * @author Veronica Liesaputra
 */
public class ParsingXML extends JDialog implements ActionListener
{
    /**
     * If this check box selected means user want to view the feedback xml file.
     */
    JCheckBox chk_feedback;
    /**
     * If this check box selected means user want to view all the images inside the
     * feedback command and command xml files.
     */
    JCheckBox chk_movie;
    /**
     * If this check box selected means user want to view the comment xml file.
     */
    JCheckBox chk_comment;
    /**
     * If this check box selected means user want to view the command xml file.
     */
    JCheckBox chk_command;
    /**
     * If this check box selected means user want to view the feedback command xml file.
     */
    JCheckBox chk_fdcommand;
    /**
     * If this check box selected means user want to view the history xml file.
     */
    JCheckBox chk_content;
    /**
     * If this check box selected means user want to view the feedback history xml file.
     */
    JCheckBox chk_fdcontent;
    /**
     * This is the field where user can enter which jar file code that they want to view
     * the xml file inside it.
     */
    JTextField txt_id;
    /**
     * This is the jar file code that user want to view.
     */
    String txt = null;
    /**
     * This is the buffered use for extracting the jar file.
     */
    static final int BUFFER = 2048;
    /**
     * This variable will hold the resource of the words that is stored in Messages.properties file.
     * The calling using messages.getString(someString) will caused someString to be translated
     * into some other string that is hold in that file.usually it will caused it to be translated
     * to the language that the user use or choose to have as stated in Locale.
     */
    private static ResourceBundle messages;

    /**
     * This constructor will make a frame-window and setting up the content pane that will allow
     * user to choose which xml file they want to view.
     * @param msg hold the resource of the words that is stored in Messages.properties file.
     */
    public ParsingXML(ResourceBundle msg)
    {
	super();
	
	setup_UIManager();
	
	messages = msg;
	setTitle(messages.getString("ViewFileTitle"));
	JFrame.setDefaultLookAndFeelDecorated(true);
	setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

	JPanel cont = new JPanel();
	cont.setLayout(new BoxLayout(cont,BoxLayout.PAGE_AXIS));
	cont.setBackground(new Color(176,208,176));

	JPanel pane = new JPanel();
	pane.setBackground(new Color(176,208,176));
	
	JLabel lbl_num = new JLabel(messages.getString("ViewCode"));
	lbl_num.setBackground(new Color(176,208,176));
	pane.add(lbl_num);

	txt_id = new JTextField(18);
	txt_id.setBackground(new Color(224,240,224));
	pane.add(txt_id);

	cont.add(pane);

	JTextArea area = new JTextArea(messages.getString("ParsingXMLText"));
	area.setOpaque(false);
	area.setEditable(false);
	area.setLineWrap(true);
	area.setWrapStyleWord(true);
	area.setBorder(new EmptyBorder(new Insets(10,10,0,10)));
	area.setBackground(new Color(176,208,176));
	cont.add(area);

	JPanel pane3 = new JPanel();
	pane3.setLayout(new BoxLayout(pane3,BoxLayout.PAGE_AXIS));
	pane3.setBackground(new Color(176,208,176));

	chk_feedback = new JCheckBox(messages.getString("ViewFeedbackFile"));
	chk_feedback.setBackground(new Color(176,208,176));
	pane3.add(chk_feedback);

	chk_fdcommand = new JCheckBox(messages.getString("ViewFeedbackCommandFile"));
	chk_fdcommand.setBackground(new Color(176,208,176));
	pane3.add(chk_fdcommand);

	chk_fdcontent = new JCheckBox(messages.getString("ViewFeedbackContentFile"));
	chk_fdcontent.setBackground(new Color(176,208,176));
	pane3.add(chk_fdcontent);

	chk_command = new JCheckBox(messages.getString("ViewCommandFile"));
	chk_command.setBackground(new Color(176,208,176));
	pane3.add(chk_command);

	pane3.setBorder(new EmptyBorder(new Insets(0,10,10,10)));

	cont.add(pane3);

	JPanel pane2 = new JPanel();
	pane2.setBackground(new Color(176,208,176));

	JButton btn = new JButton(messages.getString("View"));
	btn.setActionCommand(messages.getString("View"));
	btn.setToolTipText(messages.getString("ViewToolTip"));
	btn.setBackground(new Color(176,208,176));
	btn.setDefaultCapable(true);
	btn.addActionListener(this);
	pane2.add(btn);

	JButton btn2 = new JButton(messages.getString("Close"));
	btn2.setActionCommand(messages.getString("Close"));
	btn2.setToolTipText(messages.getString("CloseToolTip"));
	btn2.setBackground(new Color(176,208,176));
	btn2.setDefaultCapable(true);
	btn2.addActionListener(this);
	pane2.add(btn2);
	
	pane2.setBorder(new EmptyBorder(new Insets(0,10,10,10)));
	
	cont.add(pane2);

	area.setAlignmentX(Component.LEFT_ALIGNMENT);
	chk_feedback.setAlignmentX(Component.LEFT_ALIGNMENT);
	chk_command.setAlignmentX(Component.LEFT_ALIGNMENT);
	
	pane2.setAlignmentX(Component.LEFT_ALIGNMENT);
	pane.setAlignmentX(Component.LEFT_ALIGNMENT);
	pane3.setAlignmentX(Component.LEFT_ALIGNMENT);

	getContentPane().add(cont);
	
	pack();
	setBackground(new Color(176,208,176));
	setResizable(false);
	setVisible(true);
	show();
    }

    /**
     * This method will setup the UI look for each of the component.
     */
    public void setup_UIManager ()
    {
	UIManager.put("Button.select",(new Color(224,240,224)));
	UIManager.put("ToolTip.backgroundInactive",(new Color (224,240,224)));
	UIManager.put("ToolTip.background",(new Color(224,240,224)));
	UIManager.put("TabbedPane.selected",(new Color(224,240,224)));
	UIManager.put("ScrollBar.background",(new Color(176,208,176)));
	UIManager.put("ScrollBar.highlight",(new Color(224,240,224)));
	UIManager.put("ScrollBar.thumb",(new Color(224,240,224)));
	UIManager.put("ScrollBar.track",(new Color(224,240,224)));
	UIManager.put("Tree.textBackground",new Color(224,240,224));
	UIManager.put("Menu.font",new Font("Dialog",Font.PLAIN,12));
	UIManager.put("MenuItem.font",new Font("Dialog",Font.PLAIN,12));
	UIManager.put("Label.font",new Font("Dialog",Font.PLAIN,12));
	UIManager.put("ComboBox.font",new Font("Dialog",Font.PLAIN,12));
    }

    /**
     * This method will extracted all the files inside the jar file with the specified code.
     * @param code is the code for the jar file need to be extracted.
     */
    public void unZipFile (String code)
    {
	try
	    {
		BufferedOutputStream dest = null;
		FileInputStream fis = new FileInputStream("Jar"+ code+ "File.jar");
		ZipInputStream zis = new
		    ZipInputStream(new BufferedInputStream(fis));
		ZipEntry entry;
		while((entry = zis.getNextEntry()) != null)
		    {
			int count;
			byte data[] = new byte[BUFFER];
			// write the files to the disk
			String dirname;
			dirname = "xmlfeedback";
			File dir = new File(dirname);
			if (dir.isDirectory() == false)
			    dir.mkdir();

			dirname = "xmlfeedback/";
			File f = new File(dirname + entry.getName());
			if (isRightXMLExtension(f) == true)
			    {
				FileOutputStream fos =
				    new FileOutputStream(dirname + entry.getName());
				dest = new BufferedOutputStream(fos, BUFFER);
				while ((count = zis.read(data, 0, BUFFER)) != -1)
				    {
					dest.write(data, 0, count);
				    }
				dest.flush();
				dest.close();
			    }
		    }
		zis.close();
	    }
	catch (FileNotFoundException fexp) {System.out.println("No File");}
	catch(Exception e)
	    {
		e.printStackTrace();
	    }
    }

    /**
     * This method will getting the extension of the specified file.
     * @param f the file we want to know the extension.
     * @return  the extension of the file.
     */
    public String getExtension(File f)
    {
        String ext = null;
        String s = f.getName();
        int i = s.lastIndexOf('.');
	
        if (i > 0 &&  i < s.length() - 1)
	    {
		ext = s.substring(i+1).toLowerCase();
	    }
        return ext;
    }

    /**
     * This method will check whether or not the file is an xml file.
     * @param f the file we want to check.
     * @return  whether or not the file is an xml file.
     */
    public boolean isRightXMLExtension(File f)
    {
	if (f.isDirectory() == true)
	    return false;
	
	String ext = getExtension(f);

	if (ext.compareTo("xml") == 0)
	    return true;
	else
	    return false;
    }
    
    /**
     * This method will tell what the program will do when user 
     * click close button or selected any of the check boxes.
     * <br>If user select close button then it will delete all xml files
     * extracted.
     * <br> If user select chk_feedback then user will view the feedback xml file.
     * <br> If user select chk_movie then user will view all the images inside the
     *      feedback command and command xml files.
     * <br> If user select chk_comment then user will view the comment xml file.
     * <br> If user select chk_command then user will view the command xml file.
     * <br> If user select chk_fdcommand then user will view the feedback command xml file.
     * <br> If user select chk_content then user will view the history xml file.
     * <br> If user select chk_fdcontent then user will view the feedback history xml file.
     * @param e action event user did.
     */
    public void actionPerformed(ActionEvent e)
    {
	String dirname;
	dirname = "xmlfeedback/";

	if(messages.getString("Close").equals(e.getActionCommand()))
	    {
		if (txt != null)
		    {
			File f;
			f = new File(dirname + ".");
			File[] fileList;
			fileList = f.listFiles();
			
			int i;
			for ( i = 0 ; i < fileList.length ; i++ )
			    fileList[i].delete();
		    }

		System.exit(0);
	    }

	if(messages.getString("View").equals(e.getActionCommand()))
	    {
		txt = txt_id.getText();
		if ((txt ==null) || (txt.length() < 5))
		    System.out.println("must enter the id code");
		else
		    {
			unZipFile(txt);

			if (chk_feedback.isSelected() == true)
			    {
				try
				    {
					JFrame frame = new JFrame(messages.getString("Viewfeedback")
								  + txt + ".xml");
					frame.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
					JFrame.setDefaultLookAndFeelDecorated(true);
					frame.setBackground(new Color (176,208,176));
					XMLParser parser = new XMLParser(frame,messages);
					XMLReader reader = parser.makeXMLReader();
					reader.setContentHandler(parser);
					reader.parse(new InputSource(dirname + "feedback" + txt + ".xml"));
					frame.setContentPane(parser.getPane());
					frame.pack();
					frame.setVisible(true);
				    }
				catch(IOException exp) {}
				catch(SAXException exp2) {exp2.printStackTrace();}
			    }

			if (chk_command.isSelected() == true)
			    {
				try
				    {
					JFrame frame = new JFrame(messages.getString("Viewcommand")
								  + txt + ".xml");
					frame.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
					JFrame.setDefaultLookAndFeelDecorated(true);
					frame.setBackground(new Color (176,208,176));
					XMLParser parser = new XMLParser(frame,messages);
					XMLReader reader = parser.makeXMLReader();
					reader.setContentHandler(parser);
					reader.parse(new InputSource(dirname + "command" + txt + ".xml"));
					frame.setContentPane(parser.getPane());
					frame.pack();
					frame.setVisible(true);
				    }
				catch(IOException exp) {}
				catch(SAXException exp2) {}
			    }

			if (chk_fdcommand.isSelected() == true)
			    {
				try
				    {
					JFrame frame = new JFrame(messages.getString("ViewFeedbackCommandState")
								  + txt + ".xml");
					frame.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
					JFrame.setDefaultLookAndFeelDecorated(true);
					frame.setBackground(new Color (176,208,176));
					XMLParser parser = new XMLParser(frame,messages);
					XMLReader reader = parser.makeXMLReader();
					reader.setContentHandler(parser);
					reader.parse(new InputSource(dirname + "feedbackcommand" + txt + ".xml"));
					frame.setContentPane(parser.getPane());
					frame.pack();
					frame.setVisible(true);
				    }
				catch(IOException exp) {}
				catch(SAXException exp2) {}
			    }

			if (chk_fdcontent.isSelected() == true)
			    {
				try
				    {
					JFrame frame = new JFrame(messages.getString("ViewFeedbackHistoryState")
								  + txt + ".xml");
					frame.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
					JFrame.setDefaultLookAndFeelDecorated(true);
					frame.setBackground(new Color (176,208,176));
					XMLParser parser = new XMLParser(frame,messages);
					XMLReader reader = parser.makeXMLReader();
					reader.setContentHandler(parser);
					reader.parse(new InputSource(dirname + "feedbackcontent" + txt + ".xml"));
					frame.setContentPane(parser.getPane());
					frame.pack();
					frame.setVisible(true);
				    }
				catch(IOException exp) {}
				catch(SAXException exp2) {}
			    }
		    
		    }
	    }
    }

    /**
     * This is the main method to run this program just do
     * java ParsingXML
     */
    public static void main (String[] args)
    {
	Locale currentLocale = Locale.getDefault();
	ResourceBundle messages = ResourceBundle.getBundle("MessagesBundle",
							   currentLocale);
	ParsingXML form = new ParsingXML(messages);
    }
			
}






